--
-- santaPlaceable
-- Specialization for placeable Santa animation
--
-- @author	112TEC
-- @version 	v1.0
-- @date		15/12/2015
-- Modifikationen erst nach Rücksprache
-- Do not edit without my permission
--

santaPlaceable = {};
santaPlaceable_mt = Class(santaPlaceable, Placeable);

InitObjectClass(santaPlaceable, "santaPlaceable");

function santaPlaceable:new(isServer, isClient, customMt)
    local mt = customMt;
    if mt == nil then
        mt = santaPlaceable_mt;
    end;

    local self = Placeable:new(isServer, isClient, mt);

    registerObjectClassName(self, "santaPlaceable");

	self.Anim = {};	
	self.AnimNode=nil;

	self.justStarted = true;
	self.isSunOn = false;
    self.isNiceWeather = false;

	return self;
end;

function santaPlaceable:delete()
	if self.particleSystems ~= nil then
		Utils.deleteParticleSystem(self.particleSystems);
	end;
    unregisterObjectClassName(self);
    santaPlaceable:superClass().delete(self);
end;

function santaPlaceable:deleteFinal()
    santaPlaceable:superClass().deleteFinal(self);
end;

function santaPlaceable:createNode(i3dFilename, moveMode)
    if not santaPlaceable:superClass().createNode(self, i3dFilename, moveMode) then
        return false;
    end;
	self.AnimNode = getChildAt(self.nodeId, 0);
	self.particlenode = getChildAt(self.nodeId, 1);

    if self.particlenode == 0 then
        return false;
    end

    self.light = getChildAt(self.nodeId, 2);

    if self.light == 0 then
        return false;
    end
    self.lightOn = getChildAt(self.light, 0);
    if self.lightOn == 0 then
        return false;
    end

    return true;
end;

function santaPlaceable:load(xmlFilename, x,y,z, rx,ry,rz, moveMode, initRandom)
    if not santaPlaceable:superClass().load(self, xmlFilename, x,y,z, rx,ry,rz, moveMode, initRandom) then
        return false;
    end;


	local xmlFile = loadXMLFile("TempXML", xmlFilename);
	print("Specialization santaPlaceable.lua v1.0 by 112TEC")

	self.particleSystems = {}
	Utils.loadParticleSystem(xmlFile, self.particleSystems, "placeable.particleSystem", self.particlenode, true, nil, self.baseDirectory)
	Utils.setEmittingState(self.particleSystems, true);

----------------------------------------------------------------
	self.Anim.speedScale = Utils.getNoNil(getUserAttribute(self.AnimNode, "animationSpeed"),1);
	self.Anim.animCharSet = 0;
	self.Anim.animCharSet = getAnimCharacterSet(self.AnimNode);
	if self.Anim.animCharSet ~= 0 then
		local clipSource = getUserAttribute(self.AnimNode, "animationClip");
		if clipSource ~= nil then
			self.Anim.clip = getAnimClipIndex(self.Anim.animCharSet, clipSource);
			if self.Anim.clip ~= nil then
				if self.Anim.clip >= 0 then
					assignAnimTrackClip(self.Anim.animCharSet, 0, self.Anim.clip);
					setAnimTrackLoopState(self.Anim.animCharSet, 0, false);
					setAnimTrackSpeedScale(self.Anim.animCharSet, 0, self.Anim.speedScale);
					self.Anim.animDuration = getAnimClipDuration(self.Anim.animCharSet, self.Anim.clip);
				else
					print("Error:santaPlaceable.lua clip for objectIndex "..tostring(self.AnimNode).." is not usable");
				end;
			else
				print("Error:santaPlaceable.lua no clip named "..tostring(clipSource).." can be found in animation for objectIndex "..tostring(self.AnimNode).."");
			end;
		else
			print("Error:santaPlaceable.lua no clip name assigned for objectIndex "..tostring(self.AnimNode).."");
		end;
	else
		print("Error:santaPlaceable.lua no animation assigned for objectIndex "..tostring(self.AnimNode).."");
	end;
	self.Anim.trackTime = 0;
--------------------------------------
		
	delete(xmlFile);

    return true;	

end;

function santaPlaceable:update(dt)

	if not self.Anim.isEnabled then
		enableAnimTrack(self.Anim.animCharSet, self.Anim.clip);
		self.Anim.isEnabled = true;
	end;

	self.Anim.trackTime = self.Anim.trackTime + dt * self.Anim.speedScale;

	if self.Anim.trackTime > self.Anim.animDuration then
		self.Anim.trackTime = 0;
		setAnimTrackTime(self.Anim.animCharSet, self.Anim.clip, self.Anim.trackTime, true);
		disableAnimTrack(self.Anim.animCharSet, self.Anim.clip);
		self.Anim.isEnabled = false;
	end;

	if self.justStarted or self.isSunOn ~= g_currentMission.environment.isSunOn or self.isNiceWeather ~= (g_currentMission.environment.currentRain == nil) then
		self.isSunOn = g_currentMission.environment.isSunOn;
		self.isNiceWeather = g_currentMission.environment.currentRain == nil;
		self.justStarted = false;
		setVisibility(self.lightOn, not (self.isSunOn and self.isNiceWeather));
	end;
end;

function santaPlaceable:updateTick(dt)
end;

registerPlaceableType("santaPlaceable", santaPlaceable);
